CreateInstanceCallbackArgs

Struct CreateInstanceCallbackArgs 

pub struct CreateInstanceCallbackArgs<'arg, 'pnext, 'this>
where 'this: 'pnext,
{ pub extensions: &'arg mut Vec<&'static CStr>, pub create_info: &'arg mut InstanceCreateInfo<'pnext>, pub entry: &'arg Entry, /* private fields */ }
Arguments to the CreateInstanceCallback.

Fields

extensions: &'arg mut Vec<&'static CStr>

The extensions to enable for the instance. You must not remove anything from this list, but you may add to it.

create_info: &'arg mut InstanceCreateInfo<'pnext>

The create info for the instance. You may add or modify things in the pnext chain, but do not turn features off. Additionally, do not add things to the list of extensions, all changes to that member will be overwritten.

entry: &'arg Entry

Vulkan entry point.